@@ -3,13 +3,13 @@
 # Launch update process for all config files found in a particular directory.
 # See COPYING.TXT file about AWStats GNU General Public License.
 #------------------------------------------------------------------------------
-# $Revision: 1.11 $ - $Author: eldy $ - $Date: 2005/04/22 17:34:05 $
+# $Revision: 1.15 $ - $Author: eldy $ - $Date: 2006/07/23 22:57:48 $
 
 
 #------------------------------------------------------------------------------
 # Defines
 #------------------------------------------------------------------------------
-my $REVISION='$Revision: 1.11 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
+my $REVISION='$Revision: 1.15 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
 my $VERSION="1.0 (build $REVISION)";
 
 # Default value of DIRCONFIG
@@ -21,6 +21,7 @@ my $Awstats='awstats.pl';
 
 my $AwstatsDir='';
 my $AwstatsProg='';
+my $LastLine='';
 
 
 
@@ -69,8 +70,16 @@ for (0..@ARGV-1) {
 	if ($ARGV[$_] =~ /^-*h/i)     		  	 { $helpfound=1; last; }
 	if ($ARGV[$_] =~ /^-*awstatsprog=(.*)/i) { $Awstats="$1"; next; }
 	if ($ARGV[$_] =~ /^-*configdir=(.*)/i)   { $DIRCONFIG="$1"; next; }
-	if ($ARGV[$_] =~ /^-*excludeconf=(.*)/i) { $confexcluded{"$1"}=1; next; }
+	if ($ARGV[$_] =~ /^-*excludeconf=(.*)/i) {
+			#try to get the different files to exclude
+			@conftoexclude = split(/,/, $1);
+			foreach (@conftoexclude) {
+				$confexcluded{"$_"}=1;
+			}
+			next;
+	}
 	if ($ARGV[$_] =~ /^-*debug=(\d+)/i)  	 { $Debug=$1; next; }
+	if ($ARGV[$_] =~ /^-*lastline=(\d+)/i)   { $LastLine=$1; next; }
 	if ($ARGV[$_] =~ /^now/i)     		  	 { $nowfound=1; next; }
 }
 
@@ -88,14 +97,14 @@ if (!$nowfound || $helpfound || ! @ARGV) {
 	print "Where options are:\n";
 	print "  -awstatsprog=pathtoawstatspl\n";
 	print "  -configdir=directorytoscan\n";
-	print "  -excludeconf=conftoexclude (Note: awstats.model.conf is always excluded)\n";
+	print "  -excludeconf=conftoexclude[,conftoexclude2,...] (Note: awstats.model.conf is always excluded)\n";
 	print "\n";
 	exit 0;
 }
 
 debug("Scan directory $DIRCONFIG");
 
-# Scan directory $DIRCONFIG 
+# Scan directory $DIRCONFIG
 opendir(DIR, $DIRCONFIG) || error("Can't scan directory $DIRCONFIG");
 my @filesindir = grep { /^awstats\.(.*)conf$/ } sort readdir(DIR);
 closedir(DIR);
@@ -141,6 +150,10 @@ if (@files) {
 			# Define command line
 			my $command="\"$AwstatsDir/$AwstatsProg\" -update -config=$domain";
 			$command.=" -configdir=\"$DIRCONFIG\"";
+			if ($LastLine) 
+			{
+				$command.=" -lastline=$LastLine";
+			}
 			# Run command line
 			print "Running '$command' to update config $domain\n";
 			my $output = `$command 2>&1`;
@@ -148,7 +161,8 @@ if (@files) {
 		}
 	}
 } else {
-	print "No AWStats config file found in $DIRCONFIG\n";	
+	print "No AWStats config file found in $DIRCONFIG\n";
 }
 
 0;	# Do not remove this line
+
