@@ -6,7 +6,7 @@
 # alone for any other log analyzer.
 # See COPYING.TXT file about AWStats GNU General Public License.
 #-----------------------------------------------------------------------------
-# $Revision: 1.44 $ - $Author: eldy $ - $Date: 2011/08/10 14:48:38 $
+# $Revision: 1.45 $ - $Author: eldy $ - $Date: 2013/01/17 19:54:15 $
 
 use strict; no strict "refs";
 #use diagnostics;
@@ -36,7 +36,7 @@ my %TmpDNSLookup = ();
 
 # ---------- Init variables --------
 use vars qw/ $REVISION $VERSION /;
-$REVISION='$Revision: 1.44 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
+$REVISION='$Revision: 1.45 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
 $VERSION="1.2 (build $REVISION)";
 
 use vars qw/ $NBOFLINESFORBENCHMARK /;
@@ -103,6 +103,26 @@ my $bzcat_file = '\.bz2$';
 # Functions
 #-----------------------------------------------------------------------------
 
+#------------------------------------------------------------------------------
+# Function:		Add all files of a specific directory
+# Parameters:	$message
+# Input:		Directory path
+# Output:		None
+# Return:		Array with list of files
+#------------------------------------------------------------------------------
+sub addDirectory {
+    my ($dir,@list) = @_;
+    my $dirH;
+    opendir($dirH, $dir) || die ("Can't open '$dir'");
+    while ($_ = readdir($dirH) ) {
+		if (-f "$dir/$_") {
+		    push @list, "$dir/$_";
+		}
+    }
+    closedir($dirH);
+    return @list;
+}
+
 #------------------------------------------------------------------------------
 # Function:		Write an error message and exit
 # Parameters:	$message
@@ -274,6 +294,9 @@ for (0..@ARGV-1) {
 		elsif ($ARGV[$_] =~ /ignoremissing/i) { $IgnoreMissing=1; }
 		else { print "Unknown argument $ARGV[$_] ignored\n"; }
 	}
+	elsif ($ARGV[$_] =~ /addfolder=(.*)$/i) {
+   		@ParamFile = addDirectory($1, @ParamFile);
+	}
 	else {
 		push @ParamFile, $ARGV[$_];
 		$cpt++;
@@ -316,6 +339,7 @@ if (scalar @ParamFile == 0) {
 	print "  $PROG.$Extension [options] file\n";
 	print "  $PROG.$Extension [options] file1 ... filen\n";
 	print "  $PROG.$Extension [options] *.*\n";
+	print "  $PROG.$Extension [options] addfolder=dirname\n";
 	print "  perl $PROG.$Extension [options] *.* > newfile\n";
 	print "Options:\n";
 	print "  -dnslookup      make a reverse DNS lookup on IP adresses\n";
