@@ -11,13 +11,12 @@
 #		supported before attempting to retrieve via it.
 #-------------------------------------------------------
 use LWP::UserAgent;
-use HTML::TokeParser;
 
 use strict;no strict "refs";
 
 
 # variables, etc
-my $REVISION='$Revision: 1.6 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
+my $REVISION='$Revision: 1.8 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
 my $VERSION="1.0 (build $REVISION)";
 
 ############### EDIT HERE ###############
@@ -243,7 +242,7 @@ if(!($ua->is_protocol_supported('https')) && $useHTTPS) {
 	exit();
 }
 
-my $fileOutput = "";
+$fileOutput = "";
 
 # Now lets build the contents to write (or append) to urlalias file
 foreach my $newAlias (@addToAliasFile) {
@@ -307,10 +306,7 @@ sub Generate_Alias_List_Entry {
 
 	# Parse returned document for page title
 	if ($res->is_success()) {
-		my $htmldoc = $res->content;
-		my $p = HTML::Parser->new(api_version => 3);
-		$p->handler( start => \&title_handler, "tagname,self");
-		$p->parse($htmldoc);
+		$pageTitle = $res->title;
 	} else {
 		print "Failed to get page: ".$res->status_line."\n";
 		$pageTitle = "Unknown Title";
@@ -320,11 +316,3 @@ sub Generate_Alias_List_Entry {
 	}
 	return $AliasLine . $pageTitle;
 }
-
-# Handler routine for HTML::Parser
-sub title_handler {
-	return if shift ne "title";
-	my $self = shift;
-	$self->handler(text => sub { $pageTitle = shift }, "dtext");
-	$self->handler(end  => sub { shift->eof if shift eq "title"; },"tagname,self");
-}
