@@ -3,7 +3,7 @@
 # If you want to add a Browser to extend AWStats database detection capabilities,
 # you must add an entry in BrowsersSearchIDOrder and in BrowsersHashIDLib.
 #-------------------------------------------------------
-# $Revision: 1.65 $ - $Author: eldy $ - $Date: 2009/10/25 11:20:49 $
+# $Revision: 1.68 $ - $Author: eldy $ - $Date: 2012/12/05 13:14:22 $
 
 # 2006-05-15 Sean Carlos http://www.antezeta.com/awstats.html 
 # 				akregator (rss)
@@ -21,9 +21,20 @@
 #				Potu Rss-Reader http://www.potu.com/
 #				OSSProxy http://www.marketscore.com/FAQ.Aspx
 
-		
+
 #package AWSUA;
 
+# Relocated from main file for easier editing
+%BrowsersFamily = (
+	'msie'      => 1,
+	'firefox'   => 2,
+	'netscape'  => 3,
+	'svn'       => 4,
+	'opera'     => 5,
+	'safari'    => 6,
+	'chrome'    => 7,
+	'konqueror' => 8
+);
 
 # BrowsersSearchIDOrder
 # This list is used to know in which order to search Browsers IDs (Most
@@ -114,6 +125,8 @@
 'webvcr',
 'qnx\svoyager',
 # Site grabbers
+'cloudflare',
+'grabber',
 'teleport',
 'webcapture',
 'webcopier',
@@ -340,6 +353,8 @@
 'webvcr','WebVCR',
 'qnx\svoyager','QNX Voyager',
 # Site grabbers
+'cloudflare','CloudFlare',
+'grabber','Grabber',
 'teleport','TelePort Pro',
 'webcapture','Acrobat Webcapture',
 'webcopier', 'WebCopier',
@@ -477,6 +492,8 @@
 # browsers.
 #---------------------------------------------------------------------------
 %BrowsersHereAreGrabbers = (
+'cloudflare','1',
+'grabber','1',
 'teleport','1',
 'webcapture','1',
 'webcopier','1',
@@ -560,6 +577,7 @@
 'netpositive','netpositive',
 'phoenix','phoenix',
 # Site grabbers
+'grabber','grabber',
 'teleport','teleport',
 'webcapture','adobe',
 'webcopier','webcopier',
@@ -673,31 +691,56 @@
 # Source for this is http://developer.apple.com/internet/safari/uamatrix.html
 %BrowsersSafariBuildToVersionHash = 
 (
-    '48' => '0.8',
-    '51' => '0.8.1',
-    '60' => '0.8.2',
-    '73' => '0.9',
-    '74' => '1.0b2',
-    '85' => '1.0',
-    '85.5' => '1.0',
-    '85.7' => '1.0.2',
-    '85.8' => '1.0.3',
-    '85.8.1' => '1.0.3',
-    '100' => '1.1',
-    '100.1' => '1.1.1',
-    '125.7' => '1.2.2',
-    '125.8' => '1.2.2',
-    '125.9' => '1.2.3',
-    '125.11' => '1.2.4',
-    '125.12' => '1.2.4',
-    '312' => '1.3',
-    '312.3' => '1.3.1',
-    '312.3.1' => '1.3.1',
-    '412' => '2.0',
-    '412.2' => '2.0',
-    '412.2.2' => '2.0',
-    '412.5' => '2.0.1',
-    '416.12' => '2.0.2'
+    '48' 		=> '0.8',
+    '51' 		=> '0.8.1',
+    '60' 		=> '0.8.2',
+    '73' 		=> '0.9',
+    '74' 		=> '1.0b2',
+    '85'        => '1.0',
+	'85.5'      => '1.0',
+	'85.7'      => '1.0.2',
+	'85.8'      => '1.0.3',
+	'85.8.1'    => '1.0.3',
+	'100'       => '1.1',
+	'100.1'     => '1.1.1',
+	'125.7'     => '1.2.2',
+	'125.8'     => '1.2.2',
+	'125.9'     => '1.2.3',
+	'125.11'    => '1.2.4',
+	'125.12'    => '1.2.4',
+	'312'       => '1.3',
+	'312.3'     => '1.3.1',
+	'312.3.1'   => '1.3.1',
+	'312.5'     => '1.3.2',
+	'312.6'     => '1.3.2',
+	'412'       => '2.0',
+	'412.2'     => '2.0',
+	'412.2.2'   => '2.0',
+	'412.5'     => '2.0.1',
+	'413'       => '2.0.1',
+	'416.12'    => '2.0.2',
+	'416.13'    => '2.0.2',
+	'417.8'     => '2.0.3',
+	'417.9.2'   => '2.0.3',
+	'417.9.3'   => '2.0.3',
+	'419.3'     => '2.0.4',
+	'522.11.3'  => '3.0',
+	'522.12'    => '3.0.2',
+	'523.10'    => '3.0.4',
+	'523.12'    => '3.0.4',
+	'525.13'    => '3.1',
+	'525.17'    => '3.1.1',
+	'525.20'    => '3.1.1',
+	'525.20.1'  => '3.1.2',
+	'525.21'    => '3.1.2',
+	'525.22'    => '3.1.2',
+	'525.26'    => '3.2',
+	'525.26.13' => '3.2',
+	'525.27'    => '3.2.1',
+	'525.27.1'  => '3.2.1',
+	'526.11.2'  => '4.0',
+	'528.1'     => '4.0',
+	'528.16'    => '4.0'
 );
 
 
