@@ -8,7 +8,7 @@
 #-----------------------------------------------------------------------------
 # Perl Required Modules: Geo::IP or Geo::IP::PurePerl
 #-----------------------------------------------------------------------------
-# $Revision: 1.28 $ - $Author: manolamancha $ - $Date: 2010/04/30 12:36:09 $
+# $Revision: 1.31 $ - $Author: eldy $ - $Date: 2010/08/04 12:38:02 $
 
 
 # <-----
@@ -63,8 +63,10 @@ sub Init_geoip {
 	# <-----
 	# ENTER HERE CODE TO DO INIT PLUGIN ACTIONS
 	debug(" Plugin $PluginName: InitParams=$InitParams",1);
-   	my ($mode,$datafile,$override)=split(/\s+/,$InitParams,3);
+   	my ($mode,$tmpdatafile)=split(/\s+/,$InitParams,2);
+   	my ($datafile,$override)=split(/\+/,$tmpdatafile,2);
    	if (! $datafile) { $datafile="$PluginName.dat"; }
+    else { $datafile =~ s/%20/ /g; }
 	if ($type eq 'geoippureperl') {
 		if ($mode eq '' || $mode eq 'GEOIP_MEMORY_CACHE')  { $mode=Geo::IP::PurePerl::GEOIP_MEMORY_CACHE(); }
 		else { $mode=Geo::IP::PurePerl::GEOIP_STANDARD(); }
@@ -98,8 +100,7 @@ sub GetCountryCodeByAddr_geoip {
     my $param="$_[0]";
 	# <-----
 	if (! $param) { return ''; }
-	if (!$LoadedOverride){&LoadOverrideFile_geoip();}
-	my $res=$TmpDomainLookup{$param}||'';
+	my $res= TmpLookup_geoip($param);
 	if (! $res) {
 		$res=lc($gi->country_code_by_addr($param)) || 'unknown';
 		$TmpDomainLookup{$param}=$res;
@@ -120,8 +121,7 @@ sub GetCountryCodeByName_geoip {
     my $param="$_[0]";
 	# <-----
 	if (! $param) { return ''; }
-	if (!$LoadedOverride){&LoadOverrideFile_geoip();}
-	my $res=$TmpDomainLookup{$param}||'';
+	my $res = TmpLookup_geoip($param);
 	if (! $res) {
 		$res=lc($gi->country_code_by_name($param)) || 'unknown';
 		$TmpDomainLookup{$param}=$res;
@@ -165,8 +165,6 @@ sub ShowInfoHost_geoip {
         print "</th>";
 	}
 	elsif ($param) {
-		# try loading our override file if we haven't yet
-		if (!$LoadedOverride){&LoadOverrideFile_geoip();}
         my $ip=0;
 		my $key;
 		if ($param =~ /^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/) {	# IPv4 address
@@ -179,9 +177,7 @@ sub ShowInfoHost_geoip {
 		}
 		print "<td>";
 		if ($key && $ip==4) {
-			my $res;
-			if ($gi){ $res = $TmpDomainLookup{$gi->get_ip_address($param)}||''; }
-			else { $res = $TmpDomainLookup{$param}||''; }
+			my $res = TmpLookup_geoip($param);
         	if (!$res){$res=lc($gi->country_code_by_addr($param)) if $gi;}
         	if ($Debug) { debug("  Plugin $PluginName: GetCountryByIp for $param: [$res]",5); }
 		    if ($res) { print $DomainsHashIDLib{$res}?$DomainsHashIDLib{$res}:"<span style=\"color: #$color_other\">$Message[0]</span>"; }
@@ -191,10 +187,8 @@ sub ShowInfoHost_geoip {
 		    print "<span style=\"color: #$color_other\">$Message[0]</span>";
 		}
 		if (! $key) {
-			my $res;
-			if ($gi){ $res = $TmpDomainLookup{$gi->get_ip_address($param)}||''; }
-			else { $res = $TmpDomainLookup{$param}||''; }
-        	if (!$res){$res=lc($gi->country_code_by_addr($param)) if $gi;}
+			my $res = TmpLookup_geoip($param);
+        	if (!$res){$res=lc($gi->country_code_by_name($param)) if $gi;}
         	if ($Debug) { debug("  Plugin $PluginName: GetCountryByHostname for $param: [$res]",5); }
 		    if ($res) { print $DomainsHashIDLib{$res}?$DomainsHashIDLib{$res}:"<span style=\"color: #$color_other\">$Message[0]</span>"; }
 		    else { print "<span style=\"color: #$color_other\">$Message[0]</span>"; }
@@ -226,21 +220,44 @@ sub LoadOverrideFile_geoip{
 		my $conf = (exists(&Get_Config_Name) ? Get_Config_Name() : $SiteConfig);
 		if ($conf && open(GEOIPFILE,"$DirData/$PluginName.$conf.txt"))	{ $filetoload="$DirData/$PluginName.$conf.txt"; }
 		elsif (open(GEOIPFILE,"$DirData/$PluginName.txt"))	{ $filetoload="$DirData/$PluginName.txt"; }
-		else { debug("Did not find $PluginName file \"$DirData/$PluginName.txt\": $!"); }
+		else { debug("No override file \"$DirData/$PluginName.txt\": $!"); }
 	}
-	# This is the fastest way to load with regexp that I know
-	while (<GEOIPFILE>){
-		chomp $_;
-		s/\r//;
-		my @record = split(",", $_);
-		# replace quotes if they were used in the file
-		foreach (@record){ $_ =~ s/"//g; }
-		# store in hash
-		$TmpDomainLookup{$record[0]} = $record[1];
+	if ($filetoload)
+	{
+		# This is the fastest way to load with regexp that I know
+		while (<GEOIPFILE>){
+			chomp $_;
+			s/\r//;
+			my @record = split(",", $_);
+			# replace quotes if they were used in the file
+			foreach (@record){ $_ =~ s/"//g; }
+			# store in hash
+			$TmpDomainLookup{$record[0]} = $record[1];
+		}
+		close GEOIPFILE;
+        debug(" Plugin $PluginName: Overload file loaded: ".(scalar keys %TmpDomainLookup)." entries found.");
 	}
-	close GEOIPFILE;
 	$LoadedOverride = 1;
-	debug(" Plugin $PluginName: Overload file loaded: ".(scalar keys %TmpDomainLookup)." entries found.");
+	return;
+}
+
+#-----------------------------------------------------------------------------
+# PLUGIN FUNCTION: TmpLookup
+# Searches the temporary hash for the parameter value and returns the corresponding
+# GEOIP entry
+#-----------------------------------------------------------------------------
+sub TmpLookup_geoip(){
+	$param = shift;
+	if (!$LoadedOverride){&LoadOverrideFile_geoip();}
+	#my $val;
+	#if ($gi &&
+	#(($type eq 'geoip' && $gi->VERSION >= 1.30) || 
+	#  $type eq 'geoippureperl' && $gi->VERSION >= 1.17)){
+	#	$val = $TmpDomainLookup{$gi->get_ip_address($param)};
+	#}
+    #else {$val = $TmpDomainLookup{$param};}
+    #return $val || '';
+    return $TmpDomainLookup{$param}||'';
 }
 
 1;	# Do not remove this line
