@@ -6,7 +6,7 @@
 #-----------------------------------------------------------------------------
 # Perl Required Modules: Geo::IP or Geo::IP::PurePerl
 #-----------------------------------------------------------------------------
-# $Revision: 1.2 $ - $Author: manolamancha $ - $Date: 2010/04/30 12:36:09 $
+# $Revision: 1.6 $ - $Author: eldy $ - $Date: 2010/09/29 19:16:10 $
 
 
 # <-----
@@ -79,8 +79,10 @@ sub Init_geoip_asn_maxmind {
 	# <-----
 	# ENTER HERE CODE TO DO INIT PLUGIN ACTIONS
 	debug(" Plugin $PluginName: InitParams=$InitParams",1);
-   	my ($mode,$datafile,$override,$link)=split(/\s+/,$InitParams,4);
+    my ($mode,$tmpdatafile)=split(/\s+/,$InitParams,2);
+    my ($datafile,$override,$link)=split(/\+/,$tmpdatafile,3);
    	if (! $datafile) { $datafile="GeoIPASNum.dat"; }
+   	else { $datafile =~ s/%20/ /g; }
 	if ($type eq 'geoippureperl') {
 		# With pureperl with always use GEOIP_STANDARD.
 		# GEOIP_MEMORY_CACHE seems to fail with ActiveState
@@ -91,10 +93,10 @@ sub Init_geoip_asn_maxmind {
 		else { $mode=Geo::IP::GEOIP_STANDARD(); }
 	}
 	# if there is a url in the override field, move it to link
-	if (lc($override) =~ m/^http/){$link = $override;}
-	else{$OverrideFile = $override;}
+	if (lc($override) =~ m/^http/) { $link = $override; $override = ''; }
+	elsif ($override) { $override =~ s/%20/ /g; $OverrideFile=$override; }
 	if ($link){$LookupLink=$link;}
-	debug(" Plugin $PluginName: GeoIP initialized type=$type mode=$mode, link=$link",1);
+	debug(" Plugin $PluginName: GeoIP initialized type=$type mode=$mode, override=$override, link=$link",1);
 	if ($type eq 'geoippureperl') {
 		$geoip_asn_maxmind = Geo::IP::PurePerl->open($datafile, $mode);
 	} else {
@@ -258,8 +260,6 @@ sub ShowInfoHost_geoip_asn_maxmind {
         print "</th>";
 	}
 	elsif ($param) {
-		# try loading our override file if we haven't yet
-		if (!$LoadedOverride){&LoadOverrideFile_geoip_asn_maxmind();}
         my $ip=0;
 		my $key;
 		if ($param =~ /^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/) {	# IPv4 address
@@ -273,8 +273,7 @@ sub ShowInfoHost_geoip_asn_maxmind {
 		print "<td>";
 		my $asn = 0;
 		if ($key && $ip==4) {
-        	if ($geoip_asn_maxmind){$asn = $TmpLookup{$geoip_asn_maxmind->get_ip_address($param)};}
-        	else {$asn = $TmpLookup{$param};}
+        	$asn = TmpLookup_geoip_asn_maxmind($param);
         	if (!$asn && $type eq 'geoippureperl')
 			{
         		# Function org_by_addr does not exists in PurePerl but org_by_name do same
@@ -290,8 +289,7 @@ sub ShowInfoHost_geoip_asn_maxmind {
 		    debug("  Plugin $PluginName: IPv6 not supported by MaxMind Free DBs: $key",3);
 		}
 		if (! $key) {
-        	if ($geoip_asn_maxmind){$asn = $TmpLookup{$geoip_asn_maxmind->get_ip_address($param)};}
-        	else {$asn = $TmpLookup{$param};}
+        	$asn = TmpLookup_geoip_asn_maxmind($param);
         	if (!$asn && $type eq 'geoippureperl')
 			{
         		$asn=$geoip_asn_maxmind->org_by_name($param) if $geoip_asn_maxmind;
@@ -350,10 +348,7 @@ sub SectionInitHashArray_geoip_asn_maxmind {
 sub SectionProcessIp_geoip_asn_maxmind {
     my $param="$_[0]";      # Param must be an IP
 	# <-----
-	my $asn = 0;
-	if (!$LoadedOverride){&LoadOverrideFile_geoip_asn_maxmind();}
-	if ($geoip_asn_maxmind){$asn = $TmpLookup{$geoip_asn_maxmind->get_ip_address($param)};}
-        	else {$asn = $TmpLookup{$param};}
+	my $asn = TmpLookup_geoip_asn_maxmind($param);
 	if (!$asn && $type eq 'geoippureperl')
 	{
 		# Function org_by_addr does not exists in PurePerl but org_by_name do same
@@ -383,9 +378,7 @@ sub SectionProcessIp_geoip_asn_maxmind {
 sub SectionProcessHostname_geoip_asn_maxmind {
     my $param="$_[0]";      # Param must be an IP
 	# <-----
-	my $asn=0;
-	if ($geoip_asn_maxmind){$asn = $TmpLookup{$geoip_asn_maxmind->get_ip_address($param)};}
-    else {$asn = $TmpLookup{$param};}
+	my $asn = TmpLookup_geoip_asn_maxmind($param);
 	if (!$asn && $type eq 'geoippureperl')
 	{
 		$asn=$geoip_asn_maxmind->org_by_name($param) if $geoip_asn_maxmind;
@@ -493,21 +486,25 @@ sub LoadOverrideFile_geoip_asn_maxmind{
 		my $conf = (exists(&Get_Config_Name) ? Get_Config_Name() : $SiteConfig);
 		if ($conf && open(GEOIPFILE,"$DirData/$PluginName.$conf.txt"))	{ $filetoload="$DirData/$PluginName.$conf.txt"; }
 		elsif (open(GEOIPFILE,"$DirData/$PluginName.txt"))	{ $filetoload="$DirData/$PluginName.txt"; }
-		else { debug("Did not find $PluginName file \"$DirData/$PluginName.txt\": $!"); }
+		else { debug("No override file \"$DirData/$PluginName.txt\": $!"); }
 	}
-	# This is the fastest way to load with regexp that I know
-	while (<GEOIPFILE>){
-		chomp $_;
-		s/\r//;
-		my @record = split(",", $_);
-		# replace quotes if they were used in the file
-		foreach (@record){ $_ =~ s/"//g; }
-		# store in hash
-		$TmpLookup{$record[0]} = $record[1];
+	if ($filetoload)
+	{
+		# This is the fastest way to load with regexp that I know
+		while (<GEOIPFILE>){
+			chomp $_;
+			s/\r//;
+			my @record = split(",", $_);
+			# replace quotes if they were used in the file
+			foreach (@record){ $_ =~ s/"//g; }
+			# store in hash
+			$TmpLookup{$record[0]} = $record[1];
+		}
+		close GEOIPFILE;
+        debug(" Plugin $PluginName: Overload file loaded: ".(scalar keys %TmpLookup)." entries found.");
 	}
-	close GEOIPFILE;
 	$LoadedOverride = 1;
-	debug(" Plugin $PluginName: Overload file loaded: ".(scalar keys %TmpLookup)." entries found.");
+	return;
 }
 
 sub trim($)
@@ -518,4 +515,25 @@ sub trim($)
 	return $string;
 }
 
+#-----------------------------------------------------------------------------
+# PLUGIN FUNCTION: TmpLookup
+# Searches the temporary hash for the parameter value and returns the corresponding
+# GEOIP entry
+#-----------------------------------------------------------------------------
+sub TmpLookup_geoip_asn_maxmind(){
+	$param = shift;
+	if (!$LoadedOverride){&LoadOverrideFile_geoip_asn_maxmind();}
+#	my $val;
+#	if ($geoip_asn_maxmind && 
+#	(($type eq 'geoip' && $geoip_asn_maxmind->VERSION >= 1.30) || 
+#	  $type eq 'geoippureperl' && $geoip_asn_maxmind->VERSION >= 1.17)){
+#		$val = $TmpLookup{$geoip_asn_maxmind->get_ip_address($param)};
+#	}
+#    else {$val = $TmpLookup{$param};}
+#    return $val || '';
+    return $TmpLookup{$param}||'';
+    
+}
+
+
 1;	# Do not remove this line
