@@ -7,7 +7,7 @@
 #-----------------------------------------------------------------------------
 # Perl Required Modules: Geo::IP or Geo::IP::PurePerl
 #-----------------------------------------------------------------------------
-# $Revision: 1.17 $ - $Author: manolamancha $ - $Date: 2010/04/30 12:36:09 $
+# $Revision: 1.21 $ - $Author: eldy $ - $Date: 2010/08/23 21:55:34 $
 
 
 # <-----
@@ -154,10 +154,12 @@ sub Init_geoip_region_maxmind {
 	# <-----
 	# ENTER HERE CODE TO DO INIT PLUGIN ACTIONS
 	debug(" Plugin $PluginName: InitParams=$InitParams",1);
-   	my ($mode,$datafile,$override)=split(/\s+/,$InitParams,3);
+    my ($mode,$tmpdatafile)=split(/\s+/,$InitParams,2);
+    my ($datafile,$override)=split(/\+/,$tmpdatafile,2);
    	if (! $datafile) { $datafile="GeoIPRegion.dat"; }
+   	else { $datafile =~ s/%20/ /g; }
 	if ($type eq 'geoippureperl') {
-		# With pureperl with always use GEOIP_STANDARD.
+		# With pureperl we always use GEOIP_STANDARD.
 		# GEOIP_MEMORY_CACHE seems to fail with ActiveState
 		if ($mode eq '' || $mode eq 'GEOIP_MEMORY_CACHE')  { $mode=Geo::IP::PurePerl::GEOIP_STANDARD(); }
 		else { $mode=Geo::IP::PurePerl::GEOIP_STANDARD(); }
@@ -165,7 +167,7 @@ sub Init_geoip_region_maxmind {
 		if ($mode eq '' || $mode eq 'GEOIP_MEMORY_CACHE')  { $mode=Geo::IP::GEOIP_MEMORY_CACHE(); }
 		else { $mode=Geo::IP::GEOIP_STANDARD(); }
 	}
-	if ($override){$OverrideFile=$override;}
+	if ($override){ $override =~ s/%20/ /g; $OverrideFile=$override; }
 	%TmpDomainLookup=();
 	debug(" Plugin $PluginName: GeoIP initialized type=$type mode=$mode",1);
 	if ($type eq 'geoippureperl') {
@@ -393,9 +395,7 @@ sub ShowInfoHost_geoip_region_maxmind {
 		print "<td>";
 		if ($key && $ip==4) {
         	my ($res1,$res2,$countryregion)=();
-        	my @res;
-        	if ($geoip_region_maxmind){@res = @{$TmpDomainLookup{$geoip_region_maxmind->get_ip_address($param)}};}
-        	else {@res = @{$TmpDomainLookup{$param}};}
+        	my @res = TmpLookup_geoip_region_maxmind($param);
 	        if (@res){
 	        	$res1 = $res[0];
 	        	$res2 = $res[1];
@@ -427,9 +427,7 @@ sub ShowInfoHost_geoip_region_maxmind {
         }
 		if (! $key) {
         	my ($res1,$res2,$countryregion)=();
-        	my @res;
-        	if ($geoip_region_maxmind){@res = @{$TmpDomainLookup{$geoip_region_maxmind->get_ip_address($param)}};}
-        	else {@res = @{$TmpDomainLookup{$param}};}
+        	my @res = TmpLookup_geoip_region_maxmind($param);
 	        if (@res){
 	        	$res1 = $res[0];
 	        	$res2 = $res[1];
@@ -487,11 +485,8 @@ sub SectionInitHashArray_geoip_region_maxmind {
 sub SectionProcessIp_geoip_region_maxmind {
     my $param="$_[0]";      # Param must be an IP
 	# <-----
-	if (!$LoadedOverride){&LoadOverrideFile_geoip_region_maxmind();}
 	my ($res1,$res2,$countryregion)=();
-	my @res;
-    if ($geoip_region_maxmind){@res = @{$TmpDomainLookup{$geoip_region_maxmind->get_ip_address($param)}};}
-    else {@res = @{$TmpDomainLookup{$param}};}
+	my @res = TmpLookup_geoip_region_maxmind($param);
     if (@res){
       	$res1 = $res[0];
        	$res2 = $res[1];
@@ -515,11 +510,8 @@ sub SectionProcessIp_geoip_region_maxmind {
 sub SectionProcessHostname_geoip_region_maxmind {
     my $param="$_[0]";      # Param must be a hostname
 	# <-----
-	if (!$LoadedOverride){&LoadOverrideFile_geoip_region_maxmind();}
 	my ($res1,$res2,$countryregion)=();
-	my @res;
-    if ($geoip_region_maxmind){@res = @{$TmpDomainLookup{$geoip_region_maxmind->get_ip_address($param)}};}
-    else {@res = @{$TmpDomainLookup{$param}};}
+	my @res = TmpLookup_geoip_region_maxmind($param);
     if (@res){
       	$res1 = $res[0];
        	$res2 = $res[1];
@@ -623,26 +615,49 @@ sub LoadOverrideFile_geoip_region_maxmind{
 		my $conf = (exists(&Get_Config_Name) ? Get_Config_Name() : $SiteConfig);
 		if ($conf && open(GEOIPFILE,"$DirData/$PluginName.$conf.txt"))	{ $filetoload="$DirData/$PluginName.$conf.txt"; }
 		elsif (open(GEOIPFILE,"$DirData/$PluginName.txt"))	{ $filetoload="$DirData/$PluginName.txt"; }
-		else { debug("Did not find $PluginName file \"$DirData/$PluginName.txt\": $!"); }
+		else { debug("No override file \"$DirData/$PluginName.txt\": $!"); }
 	}
-	# This is the fastest way to load with regexp that I know
-	while (<GEOIPFILE>){
-		chomp $_;
-		s/\r//;
-		my @record = split(",", $_);
-		# replace quotes if they were used in the file
-		foreach (@record){ $_ =~ s/"//g; }
-		# now we need to copy our file values in the order to mimic the lookup values
-		my @res = ();
-		$res[0] = $record[1];	# country code
-		$res[1] = $record[2];	# region code
-		# store in hash
-		$TmpDomainLookup{$record[0]} = [@res];
+	if ($filetoload)
+	{
+		# This is the fastest way to load with regexp that I know
+		while (<GEOIPFILE>){
+			chomp $_;
+			s/\r//;
+			my @record = split(",", $_);
+			# replace quotes if they were used in the file
+			foreach (@record){ $_ =~ s/"//g; }
+			# now we need to copy our file values in the order to mimic the lookup values
+			my @res = ();
+			$res[0] = $record[1];	# country code
+			$res[1] = $record[2];	# region code
+			# store in hash
+			$TmpDomainLookup{$record[0]} = [@res];
+		}
+		close GEOIPFILE;
+        debug(" Plugin $PluginName: Overload file loaded: ".(scalar keys %TmpDomainLookup)." entries found.");
 	}
-	close GEOIPFILE;
 	$LoadedOverride = 1;
-	debug(" Plugin $PluginName: Overload file loaded: ".(scalar keys %TmpDomainLookup)." entries found.");
 	return;
 }
 
+#-----------------------------------------------------------------------------
+# PLUGIN FUNCTION: TmpLookup
+# Searches the temporary hash for the parameter value and returns the corresponding
+# GEOIP entry
+#-----------------------------------------------------------------------------
+sub TmpLookup_geoip_region_maxmind(){
+	$param = shift;
+	if (!$LoadedOverride){&LoadOverrideFile_geoip_region_maxmind();}
+	#my @val = ();
+	#if ($geoip_region_maxmind &&
+	#(($type eq 'geoip' && $geoip_region_maxmind->VERSION >= 1.30) || 
+	#  $type eq 'geoippureperl' && $geoip_region_maxmind->VERSION >= 1.17)){
+	#	@val = @{$TmpDomainLookup{$geoip_region_maxmind->get_ip_address($param)}};
+	#}
+    #else {@val = @{$TmpDomainLookup{$param};}}
+    #return @val;
+    if ($TmpDomainLookup{$param}) { return @{$TmpDomainLookup{$param};} }  
+    else { return; }
+}
+
 1;	# Do not remove this line
