@@ -5,7 +5,7 @@
 #-----------------------------------------------------------------------------
 # Perl Required Modules: None
 #-----------------------------------------------------------------------------
-# $Revision: 1.3 $ - $Author: manolamancha $ - $Date: 2010/04/30 14:07:46 $
+# $Revision: 1.6 $ - $Author: eldy $ - $Date: 2011/01/14 11:05:31 $
 # 
 # Changelog
 #
@@ -26,7 +26,7 @@ no strict "refs";
 # <-----
 # ENTER HERE THE MINIMUM AWSTATS VERSION REQUIRED BY YOUR PLUGIN
 # AND THE NAME OF ALL FUNCTIONS THE PLUGIN MANAGE.
-my $PluginNeedAWStatsVersion = "6.95";
+my $PluginNeedAWStatsVersion = "7.0";
 my $PluginHooksFunctions = "Init ShowGraph AddHTMLHeader";
 my $PluginName = "graphgooglechartapi";
 my $ChartProtocol = "http://";
@@ -132,6 +132,14 @@ sub ShowGraph_graphgooglechartapi() {
 		$labellength=32;
 		print Get_Img_Tag(Graph_Pie(), $title);
 	}
+	elsif ($type eq 'downloads'){
+		$labellength=32;
+		print Get_Img_Tag(Graph_Pie(), $title);
+	}
+	elsif ($type eq 'pages'){
+		$labellength=32;
+		print Get_Img_Tag(Graph_Pie(), $title);
+	}
 	elsif ($type eq 'oss'){
 		$labellength=32;
 		print Get_Img_Tag(Graph_Pie(), $title);
@@ -476,6 +484,9 @@ sub Chart_Map(){
 	# loop and dump
     my $i = 0;
     for ($i .. (scalar @$blocklabel - 1)) {
+		# fix case of uk
+        if (@$blocklabel[$i] eq 'Great Britain'){ @$blocklabel[$i] =
+'United Kingdom'; }
     	print "\tdata.setValue($i, 0, \"".@$blocklabel[$i]."\");\n";
     	print "\tdata.setValue($i, 1, ".@$valdata[$i].");\n";
     	$i++;
@@ -548,6 +559,7 @@ sub Get_Labels(){
 		}
 		$chxl .= "$temp|";
 	}
+	$chxl =~ s/&//;
 	return $chxl;
 }
 
